Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(17)

Unified Diff: third_party/crashpad/crashpad/snapshot/win/thread_snapshot_win.h

Issue 1921833002: Update Crashpad to 00d458adaf3868999eeab5341fce5bedb81d17a1 (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: win fixes Created 4 years, 8 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: third_party/crashpad/crashpad/snapshot/win/thread_snapshot_win.h
diff --git a/third_party/crashpad/crashpad/snapshot/win/thread_snapshot_win.h b/third_party/crashpad/crashpad/snapshot/win/thread_snapshot_win.h
index d746ddb4b4e377454b6d029c46a56a6f65f4b1d6..7b566885e6a04b957d16914d2dc7fdaaf0bcf2a5 100644
--- a/third_party/crashpad/crashpad/snapshot/win/thread_snapshot_win.h
+++ b/third_party/crashpad/crashpad/snapshot/win/thread_snapshot_win.h
@@ -48,14 +48,17 @@ class ThreadSnapshotWin final : public ThreadSnapshot {
//! the thread.
//! \param[in] process_reader_thread The thread within the ProcessReaderWin
//! for which the snapshot should be created.
//! \param[in] gather_indirectly_referenced_memory If `true`, adds extra
//! memory regions to the snapshot pointed to by the thread's stack.
//!
//! \return `true` if the snapshot could be created, `false` otherwise with
//! an appropriate message logged.
- bool Initialize(ProcessReaderWin* process_reader,
- const ProcessReaderWin::Thread& process_reader_thread,
- bool gather_indirectly_referenced_memory);
+ bool Initialize(
+ ProcessReaderWin* process_reader,
+ const ProcessReaderWin::Thread& process_reader_thread,
+ uint32_t* gather_indirectly_referenced_memory_bytes_remaining);
// ThreadSnapshot:
@@ -76,10 +79,10 @@ class ThreadSnapshotWin final : public ThreadSnapshot {
#endif
CPUContext context_;
MemorySnapshotWin stack_;
- internal::MemorySnapshotWin teb_;
+ MemorySnapshotWin teb_;
ProcessReaderWin::Thread thread_;
InitializationStateDcheck initialized_;
- PointerVector<internal::MemorySnapshotWin> pointed_to_memory_;
+ PointerVector<MemorySnapshotWin> pointed_to_memory_;
DISALLOW_COPY_AND_ASSIGN(ThreadSnapshotWin);
};
@@ -48,14 +48,17 @@ class ThreadSnapshotWin final : public ThreadSnapshot {
//! \param[in] process_reader_thread The thread within the ProcessReaderWin
//! for which the snapshot should be created.
- //! \param[in] gather_indirectly_referenced_memory If `true`, adds extra
- //! memory regions to the snapshot pointed to by the thread's stack.
+ //! \param[in] gather_indirectly_referenced_memory_bytes_remaining. If
+ //! non-null, add extra memory regions to the snapshot pointed to by the
+ //! thread's stack. The size of the regions added is subtracted from the
+ //! count, and when it's `0`, no more regions will be added.
//!
//! \return `true` if the snapshot could be created, `false` otherwise with

Powered by Google App Engine
This is Rietveld 408576698